| REMixed-package | R Documentation |
Suppose that we have a differential system of equations containing variables (S_{p})_{p\leq P} and R, that depends on some parameters. We define a non-linear mixed effects model from this system depending on individual parameters (\psi_i)_{i\leq N} and (\phi_i)_{i\leq N} that defines the parameters from the structural model as individuals. The first part (\psi_i)_{i\leq N} is supposed to derived from a generalized linear model for each parameter l\leq m :
h_l(\psi_{li}) = h_l(\psi_{l pop})+X_i\beta_l + \eta_{li}
with the covariates of individual i\leq N, (X_i)_{i\leq N}, random effects \eta_i=(\eta_{li})_{l\leq m}\overset{iid}{\sim}\mathcal{N}(0,\Omega), the population parameters \psi_{pop}=(\psi_{lpop})_{l\leq m} and \beta=(\beta_l)_{l\leq m_{re}} is the vector of covariates effects on parameters. The rest of the population parameters of the structural model, that hasn't random effetcs, are denoted by (\phi_i)_{i\leq N}, and are defined, for each parameters l\leq m_{no re} as
f_l(\phi_{li})=\phi_{l pop} + X_i \gamma_l
To simplify formula, we write the individual process over the time, resulting from the differential system for a set of parameters \phi_i = (\phi_{li})_{l\leq m_{no re}}, \psi_i = (\psi_{li})_{l\leq m_{re}} for individual i\leq N, as S_{p}(\cdot,\phi_i,\psi_i)=S_{pi}(\cdot), p\leq P and R(\cdot,\phi_i,\psi_i)=R_i(\cdot). We assume that individual trajectories (S_{pi})_{p\leq P,i\leq N} are observed through a direct observation model, up to a transformation g_p, p\leq P, at differents times (t_{pij})_{i\leq N,p\leq P,j\leq n_{ip}} :
Y_{pij}=g_p(S_{pi}(t_{pij}))+\epsilon_{pij}
with error \epsilon_p=(\epsilon_{pij})\overset{iid}{\sim}\mathcal N(0,\varsigma_p^2) for p\leq P. The individual trajectories (R_{i})_{i\leq N} are observed through $K$ latent processes, up to a transformation s_k, k\leq K, observed in (t_{kij})_{k\leq K,i\leq N,j\leq n_{kij}} :
Z_{kij}=\alpha_{k0}+\alpha_{k1} s_k(R_i(t_{kij}))+\varepsilon_{kij}
where \varepsilon_k\overset{iid}{\sim} \mathcal N(0,\sigma_k^2). The parameters of the model are then \theta=(\phi_{pop},\psi_{pop},B,\beta,\Omega,(\sigma^2_k)_{k\leq K},(\varsigma_p^2)_{p\leq P},(\alpha_{0k})_{k\leq K}) and \alpha=(\alpha_{1k})_{k\leq K}.
Maintainer: Auriane Gabaut aurianegabaut@gmail.com
Authors:
Ariane Bercu
Mélanie Prague
Cécile Proust-Lima
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.