| cv.remix | R Documentation |
\lambdaRegularization and Estimation in Mixed effects model, over a regularization path.
cv.remix(
project = NULL,
final.project = NULL,
dynFUN,
y,
ObsModel.transfo,
alpha,
lambda.grid = NULL,
alambda = 0.001,
nlambda = 50,
lambda_max = NULL,
eps1 = 10^(-2),
eps2 = 10^(-1),
selfInit = FALSE,
pop.set1 = NULL,
pop.set2 = NULL,
prune = NULL,
n = NULL,
parallel = TRUE,
ncores = NULL,
print = TRUE,
digits = 3,
trueValue = NULL,
unlinkBuildProject = TRUE,
max.iter = +Inf
)
project |
directory of the Monolix project (in .mlxtran). If NULL, the current loaded project is used (default is NULL). |
final.project |
directory of the final Monolix project (default add "_upd" to the Monolix project). |
dynFUN |
function computing the dynamics of interest for a set of parameters. This function need to contain every sub-function that it may needs (as it is called in a
.
See |
y |
initial condition of the mechanism model, conform to what is asked in dynFUN. If regressor used in Monolix provided a named list of vector of individual initial conditions. Each vector need to be of length 1 (same for all), or exactly the numbre of individuals (range in the same order as their id). |
ObsModel.transfo |
list containing two lists of transformations and two vectors linking each transformations to their observation model name in the Monolix project. The list should include identity transformations and be named Both
;
|
alpha |
named list of named vector " |
lambda.grid |
grid of user-suuplied penalisation parameters for the lasso regularization (if NULL, the sequence is computed based on the data). |
alambda |
if |
nlambda |
if |
lambda_max |
if |
eps1 |
integer (>0) used to define the convergence criteria for the regression parameters. |
eps2 |
integer (>0) used to define the convergence criteria for the likelihood. |
selfInit |
logical, if the SAEM is already done in the monolix project should be use as the initial point of the algorithm (if FALSE, SAEM is automatically compute according to |
pop.set1 |
population parameters setting for initialisation (see details). |
pop.set2 |
population parameters setting for iterations. |
prune |
percentage for prunning ( |
n |
number of points for gaussian quadrature (see |
parallel |
logical, if the computation should be done in parallel when possible (default TRUE). |
ncores |
number of cores for parallelization (default NULL and |
print |
logical, if the results and algotihm steps should be displayed in the console (default to TRUE). |
digits |
number of digits to print (default to 3). |
trueValue |
-for simulation purposes- named vector of true value for parameters. |
unlinkBuildProject |
logical, if the build project of each lambda should be deleted. |
max.iter |
maximum number of iteration (default 20). |
See REMixed-package for details on the model.
For each \lambda\in\Lambda, the remix is launched.
For population parameter estimation settings, see (<https://monolixsuite.slp-software.com/r-functions/2024R1/setpopulationparameterestimationsettings>).
A list of outputs of the final project and of the iterative process over each value of lambda.grid:
infoInformation about the parameters.
projectThe project path if not unlinked.
lambdaThe grid of \lambda.
BICVector of BIC values for the model built over the grid of \lambda.
BICcVector of BICc values for the model built over the grid of \lambda.
LLVector of log-likelihoods for the model built over the grid of \lambda.
LL.penVector of penalized log-likelihoods for the model built over the grid of \lambda.
resList of all REMixed results for each \lambda (see remix).
outputsList of all REMixed outputs for each \lambda (see remix).
## Not run:
project <- getMLXdir()
ObsModel.transfo = list(S=list(AB=log10),
linkS="yAB",
R=rep(list(S=function(x){x}),5),
linkR = paste0("yG",1:5))
alpha=list(alpha0=NULL,
alpha1=setNames(paste0("alpha_1",1:5),paste0("yG",1:5)))
y = c(S=5,AB=1000)
res = cv.remix(project = project,
dynFUN = dynFUN_demo,
y = y,
ObsModel.transfo = ObsModel.transfo,
alpha = alpha,
selfInit = TRUE,
eps1=10**(-2),
ncores=8,
nlambda=8,
eps2=1)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.