| dynFUN_demo | R Documentation |
Example of solver for remix and cv.remix algorithm. It is perfectly adapted for the Monolix demo project (see getMLXdir).
dynFUN_demo
dynFUN_demo
function of t, y, parms :
tvector of timepoint.
yinitial condition, named vector of form c(AB=<...>,S=<...>).
parmsnamed vector of model parameter ; should contain phi_S,delta_AB,delta_S.
Suppose you have antibodies secreting cells -S- that produces antibodies -AB- at rate \varphi_S. These two biological entities decay respectively at rate \delta_S and \delta_{AB}. The biological mechanism behind is :
\left\{\begin{matrix} \frac{d}{dt}S(t) &=& -\delta_S S(t) \\ \frac{d}{dt} AB(t) &=& \varphi_S S(t) - \delta_{AB} AB(t) \\ (S(0),AB(0)) &=& (S_0,AB_0) \end{matrix}\right.
Pasin C, Balelli I, Van Effelterre T, Bockstal V, Solforosi L, Prague M, Douoguih M, Thiébaut R, for the EBOVAC1 Consortium. 2019. Dynamics of the humoral immune response to a prime-boost Ebola vaccine: quantification and sources of variation. J Virol 93 : e00579-19. https://doi.org/10.1128/JVI.00579-19
model.pasin, getMLXdir.
t = seq(0,300,1)
y =c(AB=1000,S=5)
parms = c(phi_S = 611, delta_AB = 0.03, delta_S=0.01)
res <- dynFUN_demo(t,y,parms)
plot(res[,"time"],
log10(res[,"AB"]),
ylab="log10(AB(t))",
xlab="time (days)",
main="Antibody titer over the time",
type="l")
plot(res[,"time"],
res[,"S"],
ylab="S(t)",
xlab="time (days)",
main="Antibody secreting cells quantity over time",
type="l")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.