| indParm | R Documentation |
Generate the individual parameters of indivual whose covariates are covariates and random effects eta_i.
indParm(theta, covariates, eta_i, transfo, transfo.inv)
theta |
list with at least
|
covariates |
line data.frame of individual covariates ; |
eta_i |
named vector of random effect for each |
transfo |
named list of transformation functions |
transfo.inv |
amed list of inverse transformation functions for the individual parameter model (names must be consistent with |
The models used for the parameters are :
h_l(\psi_{li}) = h_l(\psi_{lpop})+X_i\beta_l + \eta_{li}
with h_l the transformation, \beta_l the vector of covariates effect and with \eta_i the random effects associated \psi_l parameter ;
g_k(\phi_{ki}) = g_k(\phi_{kpop})+X_i \gamma_l
with g_k the transformation and \gamma_k the vector of covariates effect associated \phi_k parameter.
a list with phi_i and psi_i parameters.
model.clairon, model.pasin.
phi_pop = c(delta_S = 0.231, delta_L = 0.000316)
psi_pop = c(delta_Ab = 0.025,phi_S = 3057, phi_L = 16.6)
gamma = NULL
covariates = data.frame(cAGE = runif(1,-15,15), G1 = rnorm(1), G2 = rnorm(1))
beta = list(delta_Ab=c(0,1.2,0),phi_S = c(0.93,0,0),phi_L=c(0,0,0.8))
theta=list(phi_pop = phi_pop,psi_pop = psi_pop,gamma = gamma, beta = beta)
eta_i = c(delta_Ab = rnorm(1,0,0.3),phi_S=rnorm(1,0,0.92),phi_L=rnorm(1,0,0.85))
transfo = list(delta_Ab=log,phi_S=log,phi_L=log)
transfo.inv = list(delta_Ab = exp,phi_S=exp,phi_L=exp)
indParm(theta,covariates,eta_i,transfo,transfo.inv)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.