| model.pasin | R Documentation |
Generate trajectory of the Humoral Immune Response to a Prime-Boost Ebola Vaccine.
model.pasin(t, y, parms)
t |
vector of time ; |
y |
initial condition, named vector of form |
parms |
named vector of model parameter ; should contain " |
The model correspond to the dynamics of the humoral response, from 7 days after the boost immunization with antibodies secreting cells -S and L, characterized by their half lives- that produces antibodies -AB- at rate \theta_S and \theta_L. All these biological entities decay at rate repectively \delta_S, \delta_L and \delta_{Ab}. Model is then defined as
\left\{\begin{matrix}\frac{d}{dt} Ab(t) &=& \theta_S S(t) + \theta_L L(t) - \delta_{Ab} Ab(t) \\ \frac{d}{dt}S(t) &=& -\delta_S S(t) \\ \frac{d}{dt} L(t) &=& -\delta_L L(t)\end{matrix}\right.
Matrix of time and observation of antibody titer Ab, and ASCs S and L.
Pasin C, Balelli I, Van Effelterre T, Bockstal V, Solforosi L, Prague M, Douoguih M, Thiébaut R, for the EBOVAC1 Consortium. 2019. Dynamics of the humoral immune response to a prime-boost Ebola vaccine: quantification and sources of variation. J Virol 93: e00579-19. https://doi.org/10.1128/JVI.00579-19
indParm, model.clairon.
y = c(Ab=0,S=5,L=5)
parms = c(theta_S = 611,
theta_L = 3.5,
delta_Ab = 0.025,
delta_S = 0.231,
delta_L = 0.000152)
t = seq(0,100,5)
res <- model.pasin(t,y,parms)
plot(res)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.